@@ -13,7 +13,7 @@ missing imports / variables:
 
 # functions.
 def check_user(id, create=False):
-	user = syst3m.User(username=id)
+	user = User(username=id)
 	response = user.check()
 	if not response.success:  return response
 	if response["success"] and not response["exists"] and create: 
@@ -21,7 +21,7 @@ def check_user(id, create=False):
 		if not response.success: return response
 	return r3sponse.success(f"Successfully checked user [{id}].")
 def check_group(id, users=[], create=False, overwrite=False):
-	group = syst3m.Group(name=id, get_users=False)
+	group = Group(name=id, get_users=False)
 	response = group.check()
 	if not response.success: return response
 	if response["success"] and not response["exists"] and create: 
